function I = f_dom(x,mu,sigma,epsilon,f_e,f_d)

% DESCRIPTION
% This function computes the free-entry condition in closed economy under the
% assumption of lognormally-distributed productivity (last equation of Sect. A1.2)

% INPUTS:
% x: productivity cutoff for serving the domestic market under the autarky regime
% k, lambda: shape and scale parameters of the (Weibull) productivity distribution
% epsilon: elasticity of substitution
% f_e: sunk entry costs
% f_d: fixed production costs

% OUTPUT:
% I: value of the free entry condition

% USAGE: I = f_dom(x,mu,sigma,epsilon,f_e,f_d);

% AUTHORS: Marco Bee, Department of Economics and Management, University of Trento; e-mail: marco.bee@unitn.it
%          Stefano Schiavo, School of International Studies and Department of Economics and Management, University of Trento and OFCE-DRIC; e-mail: stefano.schiavo@unitn.it
% This version: June 30, 2015
    if x<=0
        x = 1e-20;
    end
    a0 = (log(x)-mu)/sigma;
    phi_A_d = exp((epsilon-1)*mu+(epsilon-1)^2*sigma^2/2)*normcdf((epsilon-1)*sigma-a0)/normcdf(-a0);
    I = f_e/f_d - (1-logncdf(x,mu,sigma)) * (phi_A_d/x^(epsilon-1)-1);
end

