function f = min3fLogn(x,mu,sigma,epsilon,fD,tau,M1,M2,x01)

% DESCRIPTION
% This is the function to be minimized in order to find the values of the sunk entry costs
% and fixed export costs such that the share of eporting firms is equal to M2 under the
% assumption of lognormally-distributed productivity

% INPUTS:
% x (2 times 1 vector): sunk entry costs and fixed export costs
% mu, sigma: parameters of the (lognormal) productivity distribution
% epsilon: elasticity of substitution
% fD: fixed production costs
% M1: firm entry rate
% M2: share of exporting firms
% x01: starting value for the optimization

% OUTPUT:
% f: value of the function

% USAGE: f = min3fLogn(x,mu,sigma,epsilon,fD,tau,M1,M2,x01);

% AUTHORS: Marco Bee, Department of Economics and Management, University of Trento; e-mail: marco.bee@unitn.it
%          Stefano Schiavo, School of International Studies and Department of Economics and Management, University of Trento and OFCE-DRIC; e-mail: stefano.schiavo@unitn.it
% This version: June 30, 2015

options = optimoptions('fsolve','Display','none','maxfunevals',800000,'MaxIter',1000000,'TolFun',1e-10);   
[phid,fval1] = fsolve(@f_trade,x01,options,mu,sigma,epsilon,x(1),fD,tau,x(2));
f1 = 1-logncdf(phid,mu,sigma) - M1;
f2 = (1-logncdf(max(phid,tau*(x(2)/fD)^(1/(epsilon-1))*phid),mu,sigma)) / (1-logncdf(phid,mu,sigma)) - M2;
f = 100*f1^2+10*f2^2;
end

